@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 
 #include "templatetype.h"
 
-class ConstraintType: public TemplateType<ConstraintType>{
+class __libcore ConstraintType: public TemplateType<ConstraintType>{
+	private:
+		static QStringList type_names;
+
 	public:
 		static constexpr unsigned PrimaryKey = 1,
 		ForeignKey = 2,
@@ -38,6 +41,12 @@ class ConstraintType: public TemplateType<ConstraintType>{
 		ConstraintType(const QString &type_name);
 		ConstraintType(unsigned type_id);
 		ConstraintType();
+
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
 };
 
 #endif 
